==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/service/worker/RestartServiceWorker.java <==
package com.samelement.iot_notification.service.worker;

import android.content.Context;
import android.content.Intent;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.work.Data;
import androidx.work.ExistingWorkPolicy;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.service.AccessTokenRepository;
import com.samelement.iot_notification.service.SamService;

import java.util.concurrent.TimeUnit;

public class RestartServiceWorker extends Worker {
    private final String TAG = RestartServiceWorker.class.getName();
    private Context context;

    public RestartServiceWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
    }

    @NonNull
    @Override
    public Result doWork() {
        if (getInputData().getBoolean(IntentKey.KEY_NEED_TO_REFRESH, false)) {
            String newDevAccessToken = AccessTokenRepository.getInstance(context).refreshDevAccessToken();
            String newUserAccessToken = AccessTokenRepository.getInstance(context).refreshUserAccessToken();
            Log.d(TAG, "Refresh : dev access token " + newDevAccessToken);
            Log.d(TAG, "Refresh : user access token " + newUserAccessToken);

            WorkManager.getInstance(getApplicationContext()).cancelUniqueWork("SamServiceScheduledRefreshToken");

            Data data = new Data.Builder()
                    .putBoolean(IntentKey.KEY_NEED_TO_REFRESH, true)
                    .build();

            // start repeating check
            OneTimeWorkRequest oneTime = new OneTimeWorkRequest.Builder(RestartServiceWorker.class)
                    .setInitialDelay(12, TimeUnit.HOURS)
                    .setInputData(data)
                    .build();
            WorkManager.getInstance(getApplicationContext())
                    .beginUniqueWork("SamServiceScheduledRefreshToken", ExistingWorkPolicy.REPLACE, oneTime).enqueue();

        }

        Intent serviceIntent = new Intent(getApplicationContext(), SamService.class);
        getApplicationContext().startService(serviceIntent);

        return Result.success();
    }
}

==> 0.4.2.tar.gz: android/src/main/java/com/samelement/iot_notification/service/worker/RestartServiceWorker.java <==
package com.samelement.iot_notification.service.worker;

import android.content.Context;
import android.content.Intent;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.work.Data;
import androidx.work.ExistingWorkPolicy;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.service.AccessTokenRepository;
import com.samelement.iot_notification.service.SamService;

import java.util.concurrent.TimeUnit;

public class RestartServiceWorker extends Worker {
    private final String TAG = RestartServiceWorker.class.getName();
    private final Context context;

    public RestartServiceWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
    }

    @NonNull
    @Override
    public Result doWork() {
        if (getInputData().getBoolean(IntentKey.KEY_NEED_TO_REFRESH, false)) {
            String newDevAccessToken = AccessTokenRepository.getInstance(context).refreshDevAccessToken();
            String newUserAccessToken = AccessTokenRepository.getInstance(context).refreshUserAccessToken();
            Log.d(TAG, "Refresh : dev access token " + newDevAccessToken);
            Log.d(TAG, "Refresh : user access token " + newUserAccessToken);

            WorkManager.getInstance(getApplicationContext()).cancelUniqueWork("SamServiceScheduledRefreshToken");

            Data data = new Data.Builder()
                    .putBoolean(IntentKey.KEY_NEED_TO_REFRESH, true)
                    .build();

            // start repeating check
            OneTimeWorkRequest oneTime = new OneTimeWorkRequest.Builder(RestartServiceWorker.class)
                    .setInitialDelay(12, TimeUnit.HOURS)
                    .setInputData(data)
                    .build();
            WorkManager.getInstance(getApplicationContext())
                    .beginUniqueWork("SamServiceScheduledRefreshToken", ExistingWorkPolicy.REPLACE, oneTime).enqueue();

        }

        Intent serviceIntent = new Intent(getApplicationContext(), SamService.class);
        getApplicationContext().startService(serviceIntent);

        return Result.success();
    }
}
